package com.ruoyi.framework.recovery.controller;

import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.framework.recovery.domain.RecContent;
import com.ruoyi.framework.recovery.service.IRecContentService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 评论Controller
 * 
 * @author jin
 * @date 2024-11-16
 */
@RestController
@RequestMapping("/recovery/content")
public class RecContentController extends BaseController
{
    @Autowired
    private IRecContentService recContentService;

    /**
     * 查询评论列表
     */
    @PreAuthorize("@ss.hasPermi('recovery:content:list')")
    @GetMapping("/list")
    public TableDataInfo list(RecContent recContent)
    {
        startPage();
        List<RecContent> list = recContentService.selectRecContentList(recContent);
        return getDataTable(list);
    }

    /**
     * 导出评论列表
     */
    @PreAuthorize("@ss.hasPermi('recovery:content:export')")
    @Log(title = "评论", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RecContent recContent)
    {
        List<RecContent> list = recContentService.selectRecContentList(recContent);
        ExcelUtil<RecContent> util = new ExcelUtil<RecContent>(RecContent.class);
        util.exportExcel(response, list, "评论数据");
    }

    /**
     * 获取评论详细信息
     */
    @PreAuthorize("@ss.hasPermi('recovery:content:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(recContentService.selectRecContentById(id));
    }

    /**
     * 新增评论
     */
    @PreAuthorize("@ss.hasPermi('recovery:content:add')")
    @Log(title = "评论", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecContent recContent)
    {
        return toAjax(recContentService.insertRecContent(recContent));
    }

    /**
     * 修改评论
     */
    @PreAuthorize("@ss.hasPermi('recovery:content:edit')")
    @Log(title = "评论", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecContent recContent)
    {
        return toAjax(recContentService.updateRecContent(recContent));
    }

    /**
     * 删除评论
     */
    @PreAuthorize("@ss.hasPermi('recovery:content:remove')")
    @Log(title = "评论", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(recContentService.deleteRecContentByIds(ids));
    }
}
