package com.ruoyi.framework.recovery.controller;

import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.framework.recovery.domain.RecStallCategory;
import com.ruoyi.framework.recovery.service.IRecStallCategoryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 回收档口类型Controller
 * 
 * @author jin
 * @date 2024-11-16
 */
@RestController
@RequestMapping("/recovery/category")
public class RecStallCategoryController extends BaseController
{
    @Autowired
    private IRecStallCategoryService recStallCategoryService;

    /**
     * 查询回收档口类型列表
     */
    @PreAuthorize("@ss.hasPermi('recovery:category:list')")
    @GetMapping("/list")
    public TableDataInfo list(RecStallCategory recStallCategory)
    {
        startPage();
        List<RecStallCategory> list = recStallCategoryService.selectRecStallCategoryList(recStallCategory);
        return getDataTable(list);
    }

    /**
     * 导出回收档口类型列表
     */
    @PreAuthorize("@ss.hasPermi('recovery:category:export')")
    @Log(title = "回收档口类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RecStallCategory recStallCategory)
    {
        List<RecStallCategory> list = recStallCategoryService.selectRecStallCategoryList(recStallCategory);
        ExcelUtil<RecStallCategory> util = new ExcelUtil<RecStallCategory>(RecStallCategory.class);
        util.exportExcel(response, list, "回收档口类型数据");
    }

    /**
     * 获取回收档口类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('recovery:category:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(recStallCategoryService.selectRecStallCategoryById(id));
    }

    /**
     * 新增回收档口类型
     */
    @PreAuthorize("@ss.hasPermi('recovery:category:add')")
    @Log(title = "回收档口类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecStallCategory recStallCategory)
    {
        return toAjax(recStallCategoryService.insertRecStallCategory(recStallCategory));
    }

    /**
     * 修改回收档口类型
     */
    @PreAuthorize("@ss.hasPermi('recovery:category:edit')")
    @Log(title = "回收档口类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecStallCategory recStallCategory)
    {
        return toAjax(recStallCategoryService.updateRecStallCategory(recStallCategory));
    }

    /**
     * 删除回收档口类型
     */
    @PreAuthorize("@ss.hasPermi('recovery:category:remove')")
    @Log(title = "回收档口类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(recStallCategoryService.deleteRecStallCategoryByIds(ids));
    }
}
