package com.ruoyi.framework.recovery.controller;

import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.framework.recovery.domain.WxCredit;
import com.ruoyi.framework.recovery.service.IWxCreditService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 积分明细Controller
 * 
 * @author jin
 * @date 2024-12-01
 */
@RestController
@RequestMapping("/recovery/credit")
public class WxCreditController extends BaseController
{
    @Autowired
    private IWxCreditService wxCreditService;

    /**
     * 查询积分明细列表
     */
    @PreAuthorize("@ss.hasPermi('recovery:credit:list')")
    @GetMapping("/list")
    public TableDataInfo list(WxCredit wxCredit)
    {
        startPage();
        List<WxCredit> list = wxCreditService.selectWxCreditList(wxCredit);
        return getDataTable(list);
    }

    /**
     * 导出积分明细列表
     */
    @PreAuthorize("@ss.hasPermi('recovery:credit:export')")
    @Log(title = "积分明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WxCredit wxCredit)
    {
        List<WxCredit> list = wxCreditService.selectWxCreditList(wxCredit);
        ExcelUtil<WxCredit> util = new ExcelUtil<WxCredit>(WxCredit.class);
        util.exportExcel(response, list, "积分明细数据");
    }

    /**
     * 获取积分明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('recovery:credit:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wxCreditService.selectWxCreditById(id));
    }

    /**
     * 新增积分明细
     */
    @PreAuthorize("@ss.hasPermi('recovery:credit:add')")
    @Log(title = "积分明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WxCredit wxCredit)
    {
        return toAjax(wxCreditService.insertWxCredit(wxCredit));
    }

    /**
     * 修改积分明细
     */
    @PreAuthorize("@ss.hasPermi('recovery:credit:edit')")
    @Log(title = "积分明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WxCredit wxCredit)
    {
        return toAjax(wxCreditService.updateWxCredit(wxCredit));
    }

    /**
     * 删除积分明细
     */
    @PreAuthorize("@ss.hasPermi('recovery:credit:remove')")
    @Log(title = "积分明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wxCreditService.deleteWxCreditByIds(ids));
    }
}
