package com.ruoyi.framework.recovery.service.impl;

import java.util.Date;
import java.util.List;

import cn.hutool.core.date.DateField;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.ruoyi.framework.recovery.domain.dto.RecSaleInfoDto;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.framework.recovery.mapper.RecSaleInfoMapper;
import com.ruoyi.framework.recovery.domain.RecSaleInfo;
import com.ruoyi.framework.recovery.service.IRecSaleInfoService;

/**
 * 发售信息详情Service业务层处理
 *
 * @author jin
 * @date 2024-11-18
 */
@Service
public class RecSaleInfoServiceImpl implements IRecSaleInfoService {
    @Autowired
    private RecSaleInfoMapper recSaleInfoMapper;

    /**
     * 查询发售信息详情
     *
     * @param id 发售信息详情主键
     * @return 发售信息详情
     */
    @Override
    public RecSaleInfo selectRecSaleInfoById(Long id) {
        return recSaleInfoMapper.selectRecSaleInfoById(id);
    }

    /**
     * 查询发售信息详情列表
     *
     * @param recSaleInfo 发售信息详情
     * @return 发售信息详情
     */
    @Override
    public List<RecSaleInfo> selectRecSaleInfoList(RecSaleInfo recSaleInfo) {
        return recSaleInfoMapper.selectRecSaleInfoList(recSaleInfo);
    }

    /**
     * 新增发售信息详情
     *
     * @param dto 发售信息详情
     * @return 结果
     */
    @Override
    public int insertRecSaleInfo(RecSaleInfoDto dto) {
        RecSaleInfo recSaleInfo = new RecSaleInfo();
        Date activityTime = dto.getActivityTime();
        if (null == dto.getDurationOfTheActivity()) {
            dto.setDurationOfTheActivity(1);
        }
        DateTime endTime = DateUtil.offsetDay(activityTime, dto.getDurationOfTheActivity());
        recSaleInfo.setEventStartTime(activityTime);
        recSaleInfo.setEndTimeOfActivity(endTime);
        recSaleInfo.setCreateDate(new Date());
        return recSaleInfoMapper.insertRecSaleInfo(recSaleInfo);
    }

    /**
     * 修改发售信息详情
     *
     * @param recSaleInfo 发售信息详情
     * @return 结果
     */
    @Override
    public int updateRecSaleInfo(RecSaleInfo recSaleInfo) {
        return recSaleInfoMapper.updateRecSaleInfo(recSaleInfo);
    }

    /**
     * 批量删除发售信息详情
     *
     * @param ids 需要删除的发售信息详情主键
     * @return 结果
     */
    @Override
    public int deleteRecSaleInfoByIds(Long[] ids) {
        return recSaleInfoMapper.deleteRecSaleInfoByIds(ids);
    }

    /**
     * 删除发售信息详情信息
     *
     * @param id 发售信息详情主键
     * @return 结果
     */
    @Override
    public int deleteRecSaleInfoById(Long id) {
        return recSaleInfoMapper.deleteRecSaleInfoById(id);
    }

    @Override
    public List<RecSaleInfo> selectRecSaleInfoByTime(Date startTime, Date endTime) {
        return recSaleInfoMapper.selectRecSaleInfoByTime(startTime, endTime);
    }
}
