package com.ruoyi.framework.recovery.service.impl;

import java.util.Date;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.framework.recovery.mapper.WxCouponsMapper;
import com.ruoyi.framework.recovery.domain.WxCoupons;
import com.ruoyi.framework.recovery.service.IWxCouponsService;

/**
 * 微信优惠卷Service业务层处理
 *
 * @author jin
 * @date 2024-12-08
 */
@Service
public class WxCouponsServiceImpl implements IWxCouponsService
{
    @Autowired
    private WxCouponsMapper wxCouponsMapper;

    /**
     * 查询微信优惠卷
     *
     * @param id 微信优惠卷主键
     * @return 微信优惠卷
     */
    @Override
    public WxCoupons selectWxCouponsById(Long id)
    {
        return wxCouponsMapper.selectWxCouponsById(id);
    }

    /**
     * 查询微信优惠卷列表
     *
     * @param wxCoupons 微信优惠卷
     * @return 微信优惠卷
     */
    @Override
    public List<WxCoupons> selectWxCouponsList(WxCoupons wxCoupons)
    {
        return wxCouponsMapper.selectWxCouponsList(wxCoupons);
    }

    /**
     * 新增微信优惠卷
     *
     * @param wxCoupons 微信优惠卷
     * @return 结果
     */
    @Override
    public int insertWxCoupons(WxCoupons wxCoupons)
    {
        wxCoupons.setCreateTime(new Date());
        return wxCouponsMapper.insertWxCoupons(wxCoupons);
    }

    /**
     * 修改微信优惠卷
     *
     * @param wxCoupons 微信优惠卷
     * @return 结果
     */
    @Override
    public int updateWxCoupons(WxCoupons wxCoupons)
    {
        return wxCouponsMapper.updateWxCoupons(wxCoupons);
    }

    /**
     * 批量删除微信优惠卷
     *
     * @param ids 需要删除的微信优惠卷主键
     * @return 结果
     */
    @Override
    public int deleteWxCouponsByIds(Long[] ids)
    {
        return wxCouponsMapper.deleteWxCouponsByIds(ids);
    }

    /**
     * 删除微信优惠卷信息
     *
     * @param id 微信优惠卷主键
     * @return 结果
     */
    @Override
    public int deleteWxCouponsById(Long id)
    {
        return wxCouponsMapper.deleteWxCouponsById(id);
    }
}
